==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/PaneDragOverEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockManagerPane } from "./DockManagerPane";
import { ContentPane } from "./ContentPane";
import { PaneDragAction } from "./PaneDragAction";
/**
 * @hidden
 */
var PaneDragOverEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PaneDragOverEventArgsDetail, _super);
    function PaneDragOverEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.g = null;
        return _this;
    }
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.d.n = this.g;
        },
        enumerable: false,
        configurable: true
    });
    PaneDragOverEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.e.l("sourcePane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.e.l("panes", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "c", {
        get: function () {
            var ret_ = this.e.l("action", function (a) { return new PaneDragAction(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("action", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "f", {
        get: function () {
            var ret_ = this.e.m("isValid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.u("isValid", value_);
        },
        enumerable: false,
        configurable: true
    });
    PaneDragOverEventArgsDetail.$t = markType(PaneDragOverEventArgsDetail, 'PaneDragOverEventArgsDetail');
    return PaneDragOverEventArgsDetail;
}(Base));
export { PaneDragOverEventArgsDetail };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/PaneDragOverEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { DockManagerPane } from "./DockManagerPane";
import { ContentPane } from "./ContentPane";
import { PaneDragAction } from "./PaneDragAction";
/**
 * @hidden
 */
var PaneDragOverEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PaneDragOverEventArgsDetail, _super);
    function PaneDragOverEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.g = null;
        return _this;
    }
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.d.o = this.g;
        },
        enumerable: false,
        configurable: true
    });
    PaneDragOverEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("sourcePane", function (a) { return DockManagerPane.createFromNative(a); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("sourcePane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("panes", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("panes", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "c", {
        get: function () {
            var ret_ = this.e.m("action", function (a) { return new PaneDragAction(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("action", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneDragOverEventArgsDetail.prototype, "f", {
        get: function () {
            var ret_ = this.e.n("isValid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("isValid", value_);
        },
        enumerable: false,
        configurable: true
    });
    PaneDragOverEventArgsDetail.$t = markType(PaneDragOverEventArgsDetail, 'PaneDragOverEventArgsDetail');
    return PaneDragOverEventArgsDetail;
}(Base));
export { PaneDragOverEventArgsDetail };
